summaryrefslogtreecommitdiff
path: root/sw
diff options
context:
space:
mode:
authordennisroczek <dennisroczek@libreoffice.org>2017-03-18 13:46:00 +0000
committerCaolán McNamara <caolanm@redhat.com>2017-03-29 08:12:10 +0000
commitb0a3a48c1dc4edc652bdf7cd67db5151832f328c (patch)
treed82c27dad94b6e528507a279a58170962c0a83a1 /sw
parent26909d9de4c6e7165fc8f5d938ee6ef55b87cc5c (diff)
expand vis to visible; fix typos
* translate German source code comments * remove bogus surce code comments * remove ascii art * removed old StarOffice/Sun internal bug tracker references * remove left over from commit dcd5dee88e3c1185638b190553bef65c2ef6566f Change-Id: I3c5cce621c43e4a03afb76f4cc5a12065914e5ad Reviewed-on: https://gerrit.libreoffice.org/35404 Tested-by: Jenkins <ci@libreoffice.org> Reviewed-by: Caolán McNamara <caolanm@redhat.com> Tested-by: Caolán McNamara <caolanm@redhat.com>
Diffstat (limited to 'sw')
-rw-r--r--sw/source/core/access/acccontext.cxx12
-rw-r--r--sw/source/core/access/acccontext.hxx8
-rw-r--r--sw/source/core/access/accframe.hxx6
-rw-r--r--sw/source/core/access/accmap.cxx2
4 files changed, 14 insertions, 14 deletions
diff --git a/sw/source/core/access/acccontext.hxx b/sw/source/core/access/acccontext.hxx
index a316b7d0cad3..b5a0dd0e6837 100644
--- a/sw/source/core/access/acccontext.hxx
+++ b/sw/source/core/access/acccontext.hxx
@@ -130,7 +130,7 @@ protected:
SwCursorShell* GetCursorShell();
const SwCursorShell* GetCursorShell() const;
- // Notify all children that the vis area has changed.
+ // Notify all children that the visible area has changed.
// The SwFrame might belong to the current object or to any other child or
// grandchild.
void ChildrenScrolled( const SwFrame *pFrame, const SwRect& rOldVisArea );
@@ -139,13 +139,13 @@ protected:
// exist even if they aren't visible.
void Scrolled( const SwRect& rOldVisArea );
- // A child has been moved while setting the vis area
+ // A child has been moved while setting the visible area
void ScrolledWithin( const SwRect& rOldVisArea );
- // The has been added while setting the vis area
+ // The has been added while setting the visible area
void ScrolledIn();
- // The context has to be removed while setting the vis area
+ // The context has to be removed while setting the visible area
void ScrolledOut( const SwRect& rOldVisArea );
// Invalidate the states of all children of the specified SwFrame. The
diff --git a/sw/source/core/access/accframe.hxx b/sw/source/core/access/accframe.hxx
index a6455da18952..d7d064e626d0 100644
--- a/sw/source/core/access/accframe.hxx
+++ b/sw/source/core/access/accframe.hxx
@@ -102,7 +102,7 @@ protected:
bool bIsPagePreview );
virtual ~SwAccessibleFrame();
- // MT: Move to private area?
+ // Move to private area?
bool m_bIsAccDocUse;
public:
// Return the SwFrame this context is attached to.
@@ -115,8 +115,8 @@ public:
const sw::access::SwAccessibleChild& rChild ) const;
protected:
- // Return the bounding box of the frame clipped to the vis area. If
- // no frame is specified, use this' frame.
+ // Return the bounding box of the frame clipped to the visible area.
+ // If no frame is specified, use this' frame.
SwRect GetBounds( const SwAccessibleMap& rAccMap,
const SwFrame *pFrame = nullptr );
diff --git a/sw/source/core/access/accmap.cxx b/sw/source/core/access/accmap.cxx
index 0d4a083b6ac0..a5dd93ebd1d7 100644
--- a/sw/source/core/access/accmap.cxx
+++ b/sw/source/core/access/accmap.cxx
@@ -1071,7 +1071,7 @@ void SwAccessibleMap::InvalidateCursorPosition(
{
FireEvents();
// While firing events the current frame might have
- // been disposed because it moved out of the vis area.
+ // been disposed because it moved out of the visible area.
// Setting the cursor for such frames is useless and even
// causes asserts.
if( pAccImpl->GetFrame() )
diff --git a/sw/source/core/access/acccontext.cxx b/sw/source/core/access/acccontext.cxx
index 399a96f6c2a7..ee45f7317510 100644
--- a/sw/source/core/access/acccontext.cxx
+++ b/sw/source/core/access/acccontext.cxx
@@ -301,10 +301,10 @@ void SwAccessibleContext::ScrolledWithin( const SwRect& rOldVisArea )
void SwAccessibleContext::ScrolledIn()
{
// This accessible should be freshly created, because it
- // was not visible before. Therefore, its vis area must already
+ // was not visible before. Therefore, its visible area must already
// reflect the scrolling.
OSL_ENSURE( GetVisArea() == GetMap()->GetVisArea(),
- "Vis area of child is wrong. Did it exist already?" );
+ "Visible area of child is wrong. Did it exist already?" );
// Send child event at parent. That's all we have to do here.
const SwFrame* pParent = GetParent();
@@ -341,8 +341,8 @@ void SwAccessibleContext::ScrolledOut( const SwRect& rOldVisArea )
// all children that are existing only if they are visible. They
// are not disposed by the recursive Dispose call that follows later on,
// because this call will only dispose children that are in the
// new vis area. The children we want to dispose however are in the
// old vis area all.
ChildrenScrolled( GetFrame(), rOldVisArea );
// Broadcast a state changed event for the showing state.
@@ -860,7 +860,7 @@ awt::Rectangle SAL_CALL SwAccessibleContext::getBoundsImpl(bool bRelative)
throw uno::RuntimeException("no Window", static_cast<cppu::OWeakObject*>(this));
}
- SwRect aLogBounds( GetBounds( *(GetMap()), GetFrame() ) ); // twip rel to doc root
+ SwRect aLogBounds( GetBounds( *(GetMap()), GetFrame() ) ); // twip relative to document root
Rectangle aPixBounds( 0, 0, 0, 0 );
if( GetFrame()->IsPageFrame() &&
static_cast < const SwPageFrame * >( GetFrame() )->IsEmptyPage() )
@@ -1036,7 +1036,7 @@ void SwAccessibleContext::Dispose(bool bRecursive, bool bCanSkipInvisible)
OSL_ENSURE( GetFrame() && GetMap(), "already disposed" );
OSL_ENSURE( GetMap()->GetVisArea() == GetVisArea(),
- "invalid vis area for dispose" );
+ "invalid visible area for dispose" );
m_isDisposing = true;
@@ -341,8 +341,8 @@ void SwAccessibleContext::ScrolledOut( const SwRect& rOldVisArea )
// are not disposed by the recursive Dispose call that follows later on,
// because this call will only dispose children that are in the
- // new vis area. The children we want to dispose however are in the
- // old vis area all.
+ // new visible area. The children we want to dispose however are in the
+ // old visible area all.
ChildrenScrolled( GetFrame(), rOldVisArea );
// Broadcast a state changed event for the showing state.